pub struct KafkaClient { /* private fields */ }Expand description
Keeps all the configured Kafka producers and responsible for the routing of the messages.
Implementations
Sourceimpl KafkaClient
impl KafkaClient
Sourcepub fn builder() -> KafkaClientBuilder
pub fn builder() -> KafkaClientBuilder
Returns the KafkaClientBuilder
Sourcepub fn send_message(
&self,
topic: KafkaTopic,
message: &impl Message,
) -> Result<&str, ClientError>
pub fn send_message( &self, topic: KafkaTopic, message: &impl Message, ) -> Result<&str, ClientError>
Sends message to the provided Kafka topic.
Returns the name of the Kafka topic to which the message was produced.