pub struct KafkaParams<'a> {
pub topic_name: String,
pub config_name: Option<&'a str>,
pub params: &'a [KafkaConfigParam],
pub key_rate_limit: Option<KeyRateLimit>,
}Expand description
Config for creating a Kafka producer.
Fields
topic_name: StringThe topic names to use. Can be a single topic or multiple topics for sharding.
config_name: Option<&'a str>The Kafka config name will be used to produce data.
params: &'a [KafkaConfigParam]Parameters for the Kafka producer configuration.
key_rate_limit: Option<KeyRateLimit>Optionally, a rate limit per partition key to protect against partition imbalance.