pub struct TopicAssignments {Show 13 fields
pub events: TopicAssignment,
pub attachments: TopicAssignment,
pub transactions: TopicAssignment,
pub outcomes: TopicAssignment,
pub outcomes_billing: TopicAssignment,
pub metrics_sessions: TopicAssignment,
pub profiles: TopicAssignment,
pub replay_recordings: TopicAssignment,
pub monitors: TopicAssignment,
pub spans: TopicAssignment,
pub feedback: TopicAssignment,
pub items: TopicAssignment,
pub unused: Unused,
}Expand description
Configuration for topics.
Fields
events: TopicAssignmentSimple events topic name.
attachments: TopicAssignmentEvents with attachments topic name.
transactions: TopicAssignmentTransaction events topic name.
outcomes: TopicAssignmentOutcomes topic name.
outcomes_billing: TopicAssignmentOutcomes topic name for billing critical outcomes.
metrics_sessions: TopicAssignmentTopic name for metrics extracted from sessions, aka release health.
profiles: TopicAssignmentStacktrace topic name
replay_recordings: TopicAssignmentRecordings topic name.
monitors: TopicAssignmentMonitor check-ins.
spans: TopicAssignmentStandalone spans without a transaction.
feedback: TopicAssignmentFeedback events topic.
items: TopicAssignmentItems topic.
unused: UnusedAdditional topic assignments configured but currently unused by this Relay instance.
Implementations
Sourceimpl TopicAssignments
impl TopicAssignments
Sourcepub fn get(&self, kafka_topic: KafkaTopic) -> &TopicAssignment
pub fn get(&self, kafka_topic: KafkaTopic) -> &TopicAssignment
Get a topic assignment by KafkaTopic value